/*
   Copyright (c) 2014 by Plexim GmbH
   All rights reserved.

   A free license is granted to anyone to use this software for any legal
   non safety-critical purpose, including commercial applications, provided
   that:
   1) IT IS NOT USED TO DIRECTLY OR INDIRECTLY COMPETE WITH PLEXIM, and
   2) THIS COPYRIGHT NOTICE IS PRESERVED in its entirety.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
   OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
   SOFTWARE.
 */

#include "pil_ctrl.h"

//includes for project specific functions
#include "hal.h"
#include "main.h"

HAL_Handle drvHandleMirror;
EPWM_MIRROR EpwmMirror;
ADC_OVERRIDE AdcOverride;

bool_t PilIsAllowedFlag = TRUE; // safe initialization

bool_t PilIsAllowed()
{
	return(PilIsAllowedFlag);
}

void PilInitOverrideProbes(void)
{
	INIT_OPROBE(AdcOverride.Result0);
	INIT_OPROBE(AdcOverride.Result1);
	INIT_OPROBE(AdcOverride.Result2);
	INIT_OPROBE(AdcOverride.Result3);
	INIT_OPROBE(AdcOverride.Result4);
	INIT_OPROBE(AdcOverride.Result5);
	INIT_OPROBE(AdcOverride.Result6);
	INIT_OPROBE(AdcOverride.Result7);
}

void PilCallback(PIL_CtrlCallbackReq_t aCallbackReq)
{
	switch(aCallbackReq)
	{
		case PIL_CLBK_ENTER_NORMAL_OPERATION_REQ:
			PIL_inhibitPilSimulation();
			PilIsAllowedFlag = FALSE;
			break;

		case PIL_CLBK_LEAVE_NORMAL_OPERATION_REQ:
			PilIsAllowedFlag = TRUE;
			PIL_allowPilSimulation();
			break;

		case PIL_CLBK_INITIALIZE_SIMULATION:
			break;

		case PIL_CLBK_TERMINATE_SIMULATION:
			break;

		case PIL_CLBK_STOP_TIMERS:
			//Stop all timers
			CLK_disableTbClockSync(((HAL_Obj *)drvHandleMirror)->clkHandle);
			CLK_disablePwmClock(((HAL_Obj *)drvHandleMirror)->clkHandle,PWM_Number_1);
			CLK_disablePwmClock(((HAL_Obj *)drvHandleMirror)->clkHandle,PWM_Number_2);
			CLK_disablePwmClock(((HAL_Obj *)drvHandleMirror)->clkHandle,PWM_Number_3);
			break;

		case PIL_CLBK_START_TIMERS:
			//Start all timers
			CLK_enablePwmClock(((HAL_Obj *)drvHandleMirror)->clkHandle,PWM_Number_1);
			CLK_enablePwmClock(((HAL_Obj *)drvHandleMirror)->clkHandle,PWM_Number_2);
			CLK_enablePwmClock(((HAL_Obj *)drvHandleMirror)->clkHandle,PWM_Number_3);
			CLK_enableTbClockSync(((HAL_Obj *)drvHandleMirror)->clkHandle);
			break;
   }
}

